@@ -23,7 +23,7 @@ fit <- function(x, ...) {
 #' 
 #' @return MLModelFit class object.
 #' 
-#' @seealso  \code{\link{tune}}, \code{\link[stats]{model.frame}},
+#' @seealso  \code{\link{tune}}, \code{\link{ModelFrame}},
 #' \code{\link[recipes]{recipe}}, \code{\link{predict}}, \code{\link{varimp}}
 #' 
 #' @examples
@@ -42,6 +42,11 @@ fit.formula <- function(x, data, model, ...) {
 
 #' @rdname fit-methods
 #' 
+#' @details
+#' User-specified case weights may be specified for
+#' \code{\link[MachineShop:ModelFrame-methods]{ModelFrames}} upon
+#' creation with the \code{weights} argument in its constructor.
+#' 
 fit.ModelFrame <- function(x, model, ...) {
   .fit(getMLObject(model, "MLModel"), x)
 }
@@ -49,6 +54,10 @@ fit.ModelFrame <- function(x, model, ...) {
 
 #' @rdname fit-methods
 #' 
+#' @details
+#' Variables in a \code{recipe} may be used as case weights by defining a
+#' "case_weight" \code{\link[recipes:roles]{role}} for them.
+#' 
 fit.recipe <- function(x, model, ...) {
   .fit(getMLObject(model, "MLModel"), x)
 }
@@ -75,8 +84,6 @@ fit.recipe <- function(x, model, ...) {
   data_params <- list(y = y, nobs = nrow(mf))
   data_params$nvars <-  model@nvars(mf[1, , drop = FALSE])
   
-  fitbit(model, "x") <- x
-  fitbit(model, "y") <- y
   do.call(model@fit, args, envir = list2env(c(args, data_params))) %>%
-    asMLModelFit(paste0(model@name, "Fit"), model)
+    asMLModelFit(paste0(model@name, "Fit"), model, x, y)
 }
