@@ -105,9 +105,10 @@ setMethod("show", "MLModelTune",
     print(object@grid)
     cat("\nresamples:\n")
     print(object@resamples)
-    if (length(dim(object@resamples)) > 2) {
-      cat("Selected: Model", object@selected, " (", names(object@selected),
-          ")\n\n", sep = "")
+    model_names <- levels(object@resamples@response$Model)
+    if (length(model_names) > 1) {
+      cat("Selected: ", model_names[object@selected],
+          " (", names(object@selected), ")\n\n", sep = "")
     }
   }
 )
@@ -115,10 +116,12 @@ setMethod("show", "MLModelTune",
 
 setMethod("show", "Resamples",
   function(object) {
-    cat("An object of class \"", class(object), "\"\n\n", sep = "")
-    dns <- dimnames(object)
-    if (length(dns) > 2) cat("Models:", toString(dns[[3]]), "\n\n")
-    cat("Metrics:", toString(dns[[2]]), "\n\n")
+    cat("An object of class \"", class(object), "\"\n\n",
+        "Models: ", toString(levels(object@response$Model)), "\n\n",
+        "Metrics: ", toString(dimnames(object)[[2]]), "\n\n", sep = "")
+    if (length(object@strata)) {
+      cat("Stratification variable:", object@strata, "\n\n")
+    }
     show(object@control)
     invisible()
   }
